Module rerank

Module rerank 

Score fusion and reranking strategies.

Structs

CompositeReranker
Apply multiple rerankers in sequence.
CrossEncoderReranker
Placeholder cross-encoder reranker with a future gRPC hook.
DiversityReranker
Diversity-promoting reranker based on maximal marginal relevance.
RecencyReranker
Recency-based reranker.

Traits

Reranker
Post-retrieval reranker interface.

Functions

apply_reranker_config
Apply a configured reranker chain to search results.
mmr_select
Select a diverse subset of candidates using maximal marginal relevance.
reranker_needs_vectors
Return true when a configured reranker requires access to raw vectors.